%define ecllibdir           %{_libdir}/%{name}-%{version}

#define before_configure    true
#define _disable_libtoolize %{nil}

Name:           ecl
Version:        16.0.0
Release:        %mkrel 1
Summary:        Embeddable Common-Lisp
Group:          Development/Other
License:        LGPLv2+
URL:            https://common-lisp.net/project/ecl/
Source0:        https://common-lisp.net/project/ecl/files/release/%{version}/ecl-%{version}.tgz
# This patch was sent upstream on 4 Feb 2012.  It fixes a few warnings
# from the C compiler that indicate situations that might be dangerous at
# runtime.
Patch0:         %{name}-16.0.0-warnings.patch
# Do not use a separate thread to handle signals by default if built with
# boehm-gc support.
# This prevents a deadlock when building maxima with ecl support in
# fedora, and should handle by default these problems:
# http://trac.sagemath.org/sage_trac/ticket/11752
# http://www.mail-archive.com/ecls-list@lists.sourceforge.net/msg00644.html
Patch1:         %{name}-16.0.0-signal_handling_thread.patch
# GCC does not implement support for #pragma STDC FENV_ACCESS
Patch2:         %{name}-16.0.0-fenv-access.patch
# fix when building with -Werror=format-security, upstreamable
Patch3:         %{name}-16.0.0-end_of_line.patch

BuildRequires:  m4
BuildRequires:  texi2html
BuildRequires:  texinfo
BuildRequires:  texlive
BuildRequires:  gmp-devel
BuildRequires:  libgc-devel
BuildRequires:  libx11-devel
BuildRequires:  pkgconfig(atomic_ops)

# ECL permits to mix C code and Lisp, so users probably want gcc and
# devel packages of libraries used by ecl
Recommends:       gcc
Recommends:       libgc-devel
Recommends:       gmp-devel

%description
ECL (Embeddable Common-Lisp) is an interpreter of the Common-Lisp
language as described in the X3J13 Ansi specification, featuring CLOS
(Common-Lisp Object System), conditions, loops, etc, plus a translator
to C, which can produce standalone executables.

# no -devel package for header files is split off
# since they are required by the main package

%package doc
Summary:      Documentation for Embeddable Common-Lisp
Group:        Development/Other
Requires:     %{name} = %{version}-%{release}

%description doc
ECL (Embeddable Common-Lisp) is an interpreter of the Common-Lisp
language as described in the X3J13 Ansi specification, featuring CLOS
(Common-Lisp Object System), conditions, loops, etc, plus a translator
to C, which can produce standalone executables.

This package contains the documentation for ECL.

%prep
%setup -q
%autopatch -p0

%build
#CONFIGURE_TOP=. \
%configure2_5x \
	--enable-unicode=yes \
	--enable-c99complex \
	--enable-threads=yes \
	--with-__thread \
	--with-clx \
%ifarch x86_64
	--with-sse \
%endif
        --disable-rpath

# Parallel make does not work
make

# documentation build broken
#(cd build/doc; make)

%install
%make_install

# documentation build broken
#(cd build/doc; %%make_install)

# remove wrongly installed files
rm -rf %{buildroot}%{_libdir}/ecl-%{version}/{Copyright,LGPL}

rm -rf %{buildroot}%{_infodir}/dir
rm -rf %{buildroot}%{_docdir}/
rm -rf %{buildroot}/%{ecllibdir}/BUILD-STAMP

find %{buildroot}%{ecllibdir} -name '*.lsp' -exec chmod 0644 {} \;

%files
%license Copyright
%{_bindir}/ecl
%{_bindir}/ecl-config
%{ecllibdir}
%{_libdir}/libecl.so*
%{_includedir}/ecl
%{_mandir}/man*/*

%files doc
%doc examples


%changelog
* Sun Feb 28 2016 wally <wally> 16.0.0-1.mga6
+ Revision: 980455
- new version 16.0.0
- sync patches and configure options with Fedora
- use our build time flags

* Sun Feb 28 2016 wally <wally> 13.5.1-8.mga6
+ Revision: 980412
- add patch from Fedora to fix stack direction detector (rhbz#1193134)

* Sun Feb 21 2016 umeabot <umeabot> 13.5.1-7.mga6
+ Revision: 975243
- Mageia 6 Mass Rebuild

* Mon Nov 09 2015 daviddavid <daviddavid> 13.5.1-5.mga6
+ Revision: 899850
- rebuild for new fixed libatomic_ops 7.4.2
- fix a syntax error into ecl-12.7.1-fdr-fix-atomic_ops.patch
  * /usr/lib(64)//libatomic_ops.a': No such file or directory

* Wed Oct 15 2014 umeabot <umeabot> 13.5.1-4.mga5
+ Revision: 750049
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 13.5.1-3.mga5
+ Revision: 678924
- Mageia 5 Mass Rebuild

  + tv <tv>
    - s/uggests:/Recommends:/

* Sat Oct 19 2013 umeabot <umeabot> 13.5.1-2.mga4
+ Revision: 526001
- Mageia 4 Mass Rebuild

* Sun Jun 02 2013 kamil <kamil> 13.5.1-1.mga4
+ Revision: 435396
- rediff P0
- rediff P2 and P3
- drop P1 sighandler.patch - merged upstream
- new version 13.5.1

* Fri Jan 11 2013 umeabot <umeabot> 12.12.1-2.mga3
+ Revision: 349311
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 20 2012 kamil <kamil> 12.12.1-1.mga3
+ Revision: 333283
- disable Fedora patches
- update Source
- new version 12.12.1

* Mon Dec 03 2012 shlomif <shlomif> 12.7.1-1.mga3
+ Revision: 325910
- Fix build by making boehm-gc into the included one.

  + kamil <kamil>
    - import patches (P0,1,2,3) from Fedora:
      * ecl-12.7.1-fdr-fix-atomic_ops.patch
      * ecl-12.7.1-fdr-sighandler.patch
      * ecl-12.7.1-fdr-signal_handling_thread.patch
      * ecl-12.7.1-fdr-warnings.patch

* Thu Apr 14 2011 tv <tv> 11.1.1-2.mga1
+ Revision: 85434
- imported package ecl

